@@ -28,7 +28,6 @@ else:
 
 _JObject = None
 
-_java_lang_throwable = None
 _java_lang_RuntimeException = None
 _java_ClassLoader = None
 _java_lang_Class = None
@@ -50,9 +49,10 @@ def _initialize():
     _java_lang_Class = JClass("java.lang.Class")
 
     _java_ClassLoader = JClass('java.lang.ClassLoader').getSystemClassLoader()
+    if not _java_ClassLoader:
+        raise RuntimeError("Unable to load Java SystemClassLoader")
 
-    global _java_lang_throwable, _java_lang_RuntimeException
-    _java_lang_throwable = JClass("java.lang.Throwable")
+    global _java_lang_RuntimeException
     _java_lang_RuntimeException = JClass("java.lang.RuntimeException")
 
     # Preload needed classes
@@ -202,8 +202,23 @@ class JClass(type):
 
         return out
 
+    def __repr__(self):
+        return "<java class '%s'>"%(self.__name__)
+
 
 def _JClassNew(arg, loader=None, initialize=True):
+    params = None
+    if isinstance(arg, str):
+        if arg.endswith(">"):
+            i = arg.find("<")
+            params = arg[i+1:-1]
+            arg = arg[:i]
+            if params:
+                params = params.split(',')
+            else:
+                params = []
+            # FIXME we can check the geneic parameters better.
+
     if loader and isinstance(arg, str):
         arg = _java_lang_Class.forName(arg, initialize, loader)
 
@@ -220,8 +235,19 @@ def _JClassNew(arg, loader=None, initialize=True):
 
     # See if we have an existing class in the cache
     if name in _JCLASSES:
-        return _JCLASSES[name]
-    return _JClassFactory(name, javaClass)
+        cls = _JCLASSES[name]
+    else:
+        cls = _JClassFactory(name, javaClass)
+
+    if params is not None:
+        acceptParams = len(cls.class_.getTypeParameters())
+        if acceptParams == 0:
+            raise TypeError(
+                "Java class '%s' does not take parameters" % (cls.__name__))
+        if len(params) > 0 and len(params) != len(cls.class_.getTypeParameters()):
+            raise TypeError(
+                "Java generic class '%s' length mismatch" % (cls.__name__))
+    return cls
 
 
 class JInterface(object):
@@ -256,7 +282,7 @@ class JInterface(object):
         elif not hasattr(self, '__javavalue__'):
             raise JClass("java.lang.InstantiationException")(
                 "`%s` is an interface." % str(self.class_.getName()))
-        super(JObject, self).__init__()
+        super(JInterface, self).__init__()
 
     def __str__(self):
         return self.toString()
@@ -301,7 +327,7 @@ def _JClassFactory(name, jc):
         fname = pysafe(i.getName())
         members[fname] = i
     for jm in jc.getClassMethods():
-        members[pysafe(jm.getName())] = jm
+        members[pysafe(jm.__name__)] = jm
 
     # Apply customizers
     _jcustomizer._applyCustomizers(name, jc, bases, members)
@@ -384,24 +410,15 @@ def _getDefaultJavaObject(obj):
     if hasattr(obj, '__javaclass__'):
         return _java_lang_Class
 
+    if hasattr(obj, '__javaproxy__'):
+        return _java_lang_Object
+
     if obj == None:
         return _java_lang_Object
 
     raise TypeError(
         "Unable to determine the default type of `{0}`".format(obj.__class__))
 
-# Patch for forName
-
-
-@_jcustomizer.JImplementationFor('java.lang.Class')
-class _JavaLangClass(object):
-    @classmethod
-    def forName(cls, *args):
-        if len(args) == 1 and isinstance(args[0], str):
-            return cls._forName(args[0], True, _java_ClassLoader)
-        else:
-            return cls._forName(*args)
-
 
 def typeLookup(tp, name):
     """Fetch a descriptor from the inheritance tree.
@@ -526,7 +543,7 @@ def _jmethodDoc(method, cls, overloads):
     from textwrap import TextWrapper
     out = []
     out.append("Java method dispatch '%s' for '%s'" %
-               (method.getName(), cls.getName()))
+               (method.__name__, cls.getName()))
     out.append("")
     exceptions = []
     returns = []
@@ -573,5 +590,43 @@ def _jmethodDoc(method, cls, overloads):
     return "\n".join(out)
 
 
+def _jmethodAnnotation(method, cls, overloads):
+    """Generator for ``PyJPMethod.__annotation__`` property
+
+    Parameters:
+      method (PyJPMethod): method to generate annotations for.
+      cls (java.lang.Class): Class holding this method dispatch.
+      overloads (java.lang.reflect.Method[]): tuple holding all the methods
+        that are served by this method dispatch.
+
+    Returns:
+      The dict to use for type annotations.
+    """
+    returns = []
+
+    # Special handling if we have 1 overload
+    if len(overloads)==1:
+        ov = overloads[0]
+        out = {}
+        for i,p in enumerate(ov.getParameterTypes()):
+            out['arg%d'%i] = JClass(p)
+        out['return'] = JClass(ov.getReturnType())
+        return out
+
+    # Otherwise, we only get the return
+    for ov in overloads:
+        returns.append(ov.getReturnType())
+    returns = set(returns)
+    if len(returns) == 1:
+        return {"return": JClass([i for i in returns][0])}
+    return {}
+
+def _jmethodCode(method):
+    def call(*args):
+       return method.__call__(*args)
+    return call
+
 _jpype.setResource('GetClassMethod', _JClassNew)
 _jpype.setResource('GetMethodDoc', _jmethodDoc)
+_jpype.setResource('GetMethodAnnotations', _jmethodAnnotation)
+_jpype.setResource('GetMethodCode', _jmethodCode)
