@@ -12,7 +12,7 @@
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
-   
+
  *****************************************************************************/
 #ifndef _JPPROXY_H_
 #define _JPPROXY_H_
@@ -42,4 +42,16 @@ private:
 	JPObjectRef   m_Interfaces;
 } ;
 
+// Special wrapper for round trip returns
+class JPProxyType : public JPClass
+{
+public:
+	JPProxyType();
+	virtual~ JPProxyType();
+
+public: // JPClass implementation
+	virtual JPPyObject convertToPythonObject(jvalue val) override;
+} ;
+
+
 #endif // JPPROXY_H
