@@ -1,12 +1,6 @@
 import jpype
 import common
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
-
 class CollectionTestCase(common.JPypeTestCase):
 
     def setUp(self):
